/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: w_rdh_import.h 959 2006-03-02 14:09:21Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQHBCI_W_RDH_IMPORT_H
#define AQHBCI_W_RDH_IMPORT_H

#include "wizard.h"


class WizardRdhImport: public Wizard {
private:

public:
  WizardRdhImport(QBanking *qb,
                  WizardInfo *wInfo,
                  bool isFile,
                  QWidget* parent=0, const char* name=0,
                  bool modal=FALSE);
  virtual ~WizardRdhImport();

  virtual int exec();

};



#endif

